@@ -96,6 +96,7 @@ argslist <- c("level", "level.comb", "comb.fixed", "comb.random",
               "incr", "allincr", "addincr",
               "method", "allstudies", "MH.exact",
               "RR.cochrane", "print.CMH",
+              "pooledvar", "method.ci",
               "label.e", "label.c", "label.left", "label.right")
 setOption("argslist", argslist)
 ##
@@ -139,6 +140,14 @@ setOption("MH.exact", FALSE)
 setOption("RR.cochrane", FALSE)
 setOption("print.CMH", FALSE)
 ##
+## Additional setting for R function metacont
+##
+setOption("polledvar", FALSE)
+##
+## Additional setting for R function metaprop
+##
+setOption("method.ci", "CP")
+##
 ## Settings for R functions comparing two treatments
 ##
 setOption("label.e", "Experimental")
