@@ -3,6 +3,7 @@ metaprop <- function(event, n, studlab,
                      sm=.settings$smprop,
                      incr=.settings$incr, allincr=.settings$allincr,
                      addincr=.settings$addincr,
+                     method.ci=.settings$method.ci,
                      level=.settings$level, level.comb=.settings$level.comb,
                      comb.fixed=.settings$comb.fixed, comb.random=.settings$comb.random,
                      hakn=.settings$hakn,
@@ -60,15 +61,17 @@ metaprop <- function(event, n, studlab,
   }
   
   
-  if (!is.null(studlab))
-    studlab <- as.character(studlab)
-  else
+  if (is.null(studlab))
     studlab <- seq(along=event)
+  ##
+  if (is.factor(studlab))
+    studlab <- as.character(studlab)
   
   
   if (keepdata){
     if (nulldata){
-      data <- data.frame(.event=event, .n=n, .studlab=studlab)
+      data <- data.frame(.event=event, .n=n, .studlab=studlab,
+                         stringsAsFactors=FALSE)
       if (!missing.byvar)
         data$.byvar <- byvar
       ##
@@ -111,6 +114,10 @@ metaprop <- function(event, n, studlab,
   }
   
   
+  if (is.null(method.ci))
+    method.ci <- "CP"
+  
+  
   k.all <- length(event)
   ##
   if (k.all == 0) stop("No studies to combine in meta-analysis.")
@@ -141,10 +148,18 @@ metaprop <- function(event, n, studlab,
                      c("pft", "pas", "praw", "pln", "plogit"), nomatch = NA)
   ##
   if(is.na(imeth) || imeth==0)
-    stop("sm should be \"PFT\", \"PAS\", \"PRAW\", \"PLN\", or \"PLOGIT\"")
+    stop("sm should be \"PLOGIT\", \"PLN\", \"PFT\", \"PAS\", or \"PRAW\"")
   ##
   sm <- c("PFT", "PAS", "PRAW", "PLN", "PLOGIT")[imeth]
   ##
+  imci <- charmatch(tolower(method.ci),
+                     c("cp", "ws", "wscc", "ac", "sa", "sacc", "nasm"), nomatch = NA)
+  ##
+  if(is.na(imci) || imci==0)
+    stop("method.ci should be \"CP\", \"WS\", \"WSCC\", \"AC\", \"SA\", \"SACC\", or \"NAsm\"")
+  ##
+  method.ci <- c("CP", "WS", "WSCC", "AC", "SA", "SACC", "NAsm")[imci]
+  ##
   if (any(n < 10) & sm=="PFT")
     warning("Sample size very small (below 10) in at least one study. Accordingly, backtransformation for pooled effect may be misleading for Freeman-Tukey double arcsine transformation. Please look at results for other transformations (e.g. sm='PAS' or sm='PLOGIT'), too.")
   
@@ -266,6 +281,70 @@ metaprop <- function(event, n, studlab,
                  level.predict=level.predict)
   
   
+  NAs <- rep(NA, k.all)
+  ##
+  if (method.ci=="CP"){
+    lower.study <- upper.study <- NAs
+    for (i in 1:k.all){
+      cint <- binom.test(event[i], n[i], conf.level=level)
+      ##
+      lower.study[i] <- cint$conf.int[[1]]
+      upper.study[i] <- cint$conf.int[[2]]
+    }
+  }
+  ##
+  else if (method.ci=="WS")
+    ci.study <- ciWilsonScore(event, n, level=level)
+  ##
+  else if (method.ci=="WSCC")
+    ci.study <- ciWilsonScore(event, n, level=level, correct=TRUE)
+  ##
+  else if (method.ci=="AC")
+    ci.study <- ciAgrestiCoull(event, n, level=level)
+  ##
+  else if (method.ci=="SA")
+    ci.study <- ciSimpleAsymptotic(event, n, level=level)
+  ##
+  else if (method.ci=="SACC")
+    ci.study <- ciSimpleAsymptotic(event, n, level=level, correct=TRUE)
+  ##
+  else if (method.ci=="NAsm"){
+    ci.study <- ci(TE, seTE, level=level)
+  }
+  
+  
+  if (method.ci!="CP"){
+    lower.study <- ci.study$lower
+    upper.study <- ci.study$upper
+  }
+  
+  
+  if (method.ci=="NAsm"){
+    if (sm=="PLN"){
+      lower.study <- exp(lower.study)
+      upper.study <- exp(upper.study)
+    }
+    ##
+    else if (sm=="PLOGIT"){
+      lower.study <- logit2p(lower.study)
+      upper.study <- logit2p(upper.study)
+    }
+    ##
+    else if (sm=="PAS"){
+      lower.study <- asin2p(lower.study, value="lower")
+      upper.study <- asin2p(upper.study, value="upper")
+    }
+    ##
+    else if (sm=="PFT"){
+      lower.study <- asin2p(lower.study, n, value="lower")
+      upper.study <- asin2p(upper.study, n, value="upper")
+    }
+    ##
+    lower.study[lower.study<0] <- 0
+    upper.study[upper.study>1] <- 1
+  }
+  
+  
   if (m$k>=3){
     seTE.predict <- sqrt(m$seTE.random^2 + m$tau^2)
     ci.p <- ci(m$TE.random, seTE.predict, level.predict, m$k-2)
@@ -308,14 +387,16 @@ metaprop <- function(event, n, studlab,
   res <- list(event=event, n=n,
               studlab=studlab,
               TE=TE, seTE=seTE,
+              lower=lower.study, upper=upper.study,
+              zval=NAs, pval=NAs,
               w.fixed=m$w.fixed, w.random=m$w.random,
               ##
               TE.fixed=m$TE.fixed, seTE.fixed=m$seTE.fixed,
               lower.fixed=m$lower.fixed, upper.fixed=m$upper.fixed,
-              zval.fixed=m$zval.fixed, pval.fixed=m$pval.fixed,
+              zval.fixed=NA, pval.fixed=NA,
               TE.random=m$TE.random, seTE.random=m$seTE.random,
               lower.random=m$lower.random, upper.random=m$upper.random,
-              zval.random=m$zval.random, pval.random=m$pval.random,
+              zval.random=NA, pval.random=NA,
               ##
               seTE.predict=seTE.predict,
               lower.predict=p.lower, upper.predict=p.upper,
@@ -340,6 +421,7 @@ metaprop <- function(event, n, studlab,
               allincr=allincr,
               addincr=addincr,
               incr.event=incr.event,
+              method.ci=method.ci,
               level=level, level.comb=level.comb,
               comb.fixed=comb.fixed,
               comb.random=comb.random,
